
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef GC_ENUMTYPES_H_
#define GC_ENUMTYPES_H_

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "/build/gnome-characters/src/build/../gnome-characters/lib/gc.h" */
GType gc_category_get_type (void);
#define GC_TYPE_CATEGORY (gc_category_get_type ())
GType gc_search_error_get_type (void);
#define GC_TYPE_SEARCH_ERROR (gc_search_error_get_type ())
GType gc_search_flag_get_type (void);
#define GC_TYPE_SEARCH_FLAG (gc_search_flag_get_type ())
G_END_DECLS

#endif /* GC_ENUMTYPES_H_ */

/* Generated data ends here */

